@@ -19,6 +19,8 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 """Generate hillshade for a DEM.
+
+Output uses GeoTIFF format and Int16 pixel values.
  
 Usage: python gdal_shade.py src dst
 
@@ -41,4 +43,4 @@ if __name__ == '__main__':
         usage()
         sys.exit(1)
 
-    gdalhelper.gdal_shade(src, dst)
+    gdalhelper.hillshade(src, dst)
